pub enum DnsTarget {
PreferHigher {
host: String,
port: u16,
},
Dns4 {
host: String,
port: u16,
},
Dns6 {
host: String,
port: u16,
},
}Variants
PreferHigher
“PreferHigher” is encoded as dns, specifying that the highest IP stack available should be used
Dns4
Dns6
Implementations
Sourceimpl DnsTarget
impl DnsTarget
pub fn includes_ipv6(&self) -> bool
pub fn includes_ipv4(&self) -> bool
Sourcepub fn host(&self) -> &str
pub fn host(&self) -> &str
Host string, without port if present
Not all DNS records have a constant, known port; See SRV records
Sourcepub fn port(&self) -> Option<u16>
pub fn port(&self) -> Option<u16>
Exposed port for the specified address
Not all DNS records have a constant, known port; See SRV records
Sourcepub fn contains(&self, addr: &SocketAddr, check_port: bool) -> bool
pub fn contains(&self, addr: &SocketAddr, check_port: bool) -> bool
Checks that a SocketAddr is valid in the range of the specified DNS class